#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-default-instances-containers
version:              0.1.0.3
visibility:           public
id:
    data-default-instances-containers-0.1.0.3-8ELlrcZVmwsaz5lkNw4uJ

key:
    data-default-instances-containers-0.1.0.3-8ELlrcZVmwsaz5lkNw4uJ

license:              BSD-3-Clause
copyright:            (c) 2013 Lukas Mai
maintainer:           <lukasmai.403+hackage@gmail.com>
author:               Lukas Mai
synopsis:             Default instances for types in containers
description:
    This module defines '\''Default'\'' instances for the types '\''S.Set'\'', '\''M.Map'\'',
    '\''IntMap'\'', '\''IntSet'\'', '\''Seq'\'', and '\''Tree'\''.

category:             Data
abi:                  5fe28f8626a3ff2a6cd5e281e2c4071d
exposed:              True
exposed-modules:      Data.Default.Instances.Containers
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/data-default-instances-containers-0.1.0.3

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/data-default-instances-containers-0.1.0.3

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/data-default-instances-containers-0.1.0.3

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-default-instances-containers
hs-libraries:
    HSdata-default-instances-containers-0.1.0.3-8ELlrcZVmwsaz5lkNw4uJ

depends:
    base-4.18.2.1 containers-0.6.7
    data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc

haddock-interfaces:
    /usr/share/doc/haskell-data-default-instances-containers/html/data-default-instances-containers.haddock

haddock-html:
    /usr/share/doc/haskell-data-default-instances-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

